==> ejc-probid-impl-3.0.0-20220715.082857-6-sources.jar: com/ejianc/business/pay/bean/PayBackRecordEntity.java <==
package com.ejianc.business.pay.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 保证金缴纳-退还记录实体
 *
 * @author generator
 */
@TableName("ejc_probid_bond_pay_sub_back_record")
public class PayBackRecordEntity extends BaseEntity {
	private static final long serialVersionUID = 3664986928418889887L;

	@TableField(value = "employee_id")
	private Long employeeId; // 经办人id
	@TableField(value = "employee_name")
	private String employeeName; // 经办人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "effective_date")
	private Date effectiveDate; // 生效日期
	@TableField(value = "bill_code")
	private String billCode; // 单据编码
	@TableField(value = "bill_name")
	private String billName; // 单据名称
	@TableField(value = "bill_type")
	private String billType; // 单据类型
	@TableField(value = "bill_state")
	private Integer billState; // 单据状态
	@TableField(value = "bill_state_name")
	private String billStateName; // 单据状态名称
	@TableField(value = "source_bond_back_id")
	private Long sourceBondBackId; // 保证金退还id
	@TableField(value = "source_bill_code")
	private String sourceBillCode; // 保证金退还编码
	@TableField(value = "source_bill_name")
	private String sourceBillName; // 保证金退还名称
	@TableField(value = "back_mny")
	private BigDecimal backMny; // 退还金额
	@TableField(value = "back_date")
	private Date backDate; // 退还日期
	@TableField(value = "back_memo")
	private String backMemo; // 说明
	@TableField(value = "bond_pay_id")
	private Long bondPayId; // 保证金缴纳id


	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getSourceBondBackId() {
		return sourceBondBackId;
	}

	public void setSourceBondBackId(Long sourceBondBackId) {
		this.sourceBondBackId = sourceBondBackId;
	}

	public String getSourceBillCode() {
		return sourceBillCode;
	}

	public void setSourceBillCode(String sourceBillCode) {
		this.sourceBillCode = sourceBillCode;
	}

	public String getSourceBillName() {
		return sourceBillName;
	}

	public void setSourceBillName(String sourceBillName) {
		this.sourceBillName = sourceBillName;
	}

	public BigDecimal getBackMny() {
		return backMny;
	}

	public void setBackMny(BigDecimal backMny) {
		this.backMny = backMny;
	}

	public Date getBackDate() {
		return backDate;
	}

	public void setBackDate(Date backDate) {
		this.backDate = backDate;
	}

	public String getBackMemo() {
		return backMemo;
	}

	public void setBackMemo(String backMemo) {
		this.backMemo = backMemo;
	}

	public Long getBondPayId() {
		return bondPayId;
	}

	public void setBondPayId(Long bondPayId) {
		this.bondPayId = bondPayId;
	}

}

==> ejc-probid-impl-3.0.0-20220726.073027-51-sources.jar: com/ejianc/business/pay/bean/PayBackRecordEntity.java <==
package com.ejianc.business.pay.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 保证金缴纳-退还记录实体
 *
 * @author generator
 */
@TableName("ejc_probid_bond_pay_sub_back_record")
public class PayBackRecordEntity extends BaseEntity {
	private static final long serialVersionUID = 3664986928418889887L;

	@TableField(value = "source_employee_id")
	private Long sourceEmployeeId; // 经办人id
	@TableField(value = "source_employee_name")
	private String sourceEmployeeName; // 经办人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "effective_date")
	private Date effectiveDate; // 生效日期
	@TableField(value = "bill_code")
	private String billCode; // 单据编码
	@TableField(value = "bill_name")
	private String billName; // 单据名称
	@TableField(value = "bill_type")
	private String billType; // 单据类型
	@TableField(value = "bill_state")
	private Integer billState; // 单据状态
	@TableField(value = "bill_state_name")
	private String billStateName; // 单据状态名称
	@TableField(value = "source_bond_back_id")
	private Long sourceBondBackId; // 保证金退还id
	@TableField(value = "source_bill_code")
	private String sourceBillCode; // 保证金退还编码
	@TableField(value = "source_bill_name")
	private String sourceBillName; // 保证金退还名称
	@TableField(value = "source_back_mny")
	private BigDecimal sourceBackMny; // 退还金额
	@TableField(value = "source_back_date")
	private Date sourceBackDate; // 退还日期
	@TableField(value = "source_back_memo")
	private String sourceBackMemo; // 说明
	@TableField(value = "bond_pay_id")
	private Long bondPayId; // 保证金缴纳id


	public Long getSourceEmployeeId() {
		return sourceEmployeeId;
	}

	public void setSourceEmployeeId(Long sourceEmployeeId) {
		this.sourceEmployeeId = sourceEmployeeId;
	}

	public String getSourceEmployeeName() {
		return sourceEmployeeName;
	}

	public void setSourceEmployeeName(String sourceEmployeeName) {
		this.sourceEmployeeName = sourceEmployeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getSourceBondBackId() {
		return sourceBondBackId;
	}

	public void setSourceBondBackId(Long sourceBondBackId) {
		this.sourceBondBackId = sourceBondBackId;
	}

	public String getSourceBillCode() {
		return sourceBillCode;
	}

	public void setSourceBillCode(String sourceBillCode) {
		this.sourceBillCode = sourceBillCode;
	}

	public String getSourceBillName() {
		return sourceBillName;
	}

	public void setSourceBillName(String sourceBillName) {
		this.sourceBillName = sourceBillName;
	}

	public BigDecimal getSourceBackMny() {
		return sourceBackMny;
	}

	public void setSourceBackMny(BigDecimal sourceBackMny) {
		this.sourceBackMny = sourceBackMny;
	}

	public Date getSourceBackDate() {
		return sourceBackDate;
	}

	public void setSourceBackDate(Date sourceBackDate) {
		this.sourceBackDate = sourceBackDate;
	}

	public String getSourceBackMemo() {
		return sourceBackMemo;
	}

	public void setSourceBackMemo(String sourceBackMemo) {
		this.sourceBackMemo = sourceBackMemo;
	}

	public Long getBondPayId() {
		return bondPayId;
	}

	public void setBondPayId(Long bondPayId) {
		this.bondPayId = bondPayId;
	}

}
